@@ -12,6 +12,7 @@ from PIL import ImageGrab
 from pynput_robocorp.mouse import Listener
 from RPA.core.geometry import Region
 from RPA.core.windows import ElementInspector, RecordElement, WindowsElements
+from RPA.core.windows.context import ElementNotFound
 
 LOCATOR_VERSION = 1.0
 
@@ -160,21 +161,26 @@ class WindowsDriver:
 
     def validate(self, window: str, value: str) -> MatchedWindowsLocators:
         self.logger.info("Validate=%s, %s", window, value)
-        with auto.UIAutomationInitializerInThread(debug=True):
-            locators: MatchedWindowsLocators = {"matches": []}
-            self._focus_active_window(window)
-            root = self._windows_elements.get_element(f"name:{window}")
-            element = self._windows_elements.get_element(value, 8, root)
-            if element and hasattr(element, "name") and hasattr(element, "locator"):
-                locators["matches"].append(
-                    {
-                        "window": window,
-                        "name": element.name,
-                        "value": element.locator,
-                        "version": LOCATOR_VERSION,
-                        "screenshot": Rectangle.from_element(element).get_screenshot(),
-                    }
-                )
+        locators: MatchedWindowsLocators = {"matches": []}
+        try:
+            with auto.UIAutomationInitializerInThread(debug=True):
+                self._focus_active_window(window)
+                root = self._windows_elements.get_element(f"name:{window}")
+                element = self._windows_elements.get_element(value, 8, root)
+                if element and hasattr(element, "name") and hasattr(element, "locator"):
+                    locators["matches"].append(
+                        {
+                            "window": window,
+                            "name": element.name,
+                            "value": element.locator,
+                            "version": LOCATOR_VERSION,
+                            "screenshot": Rectangle.from_element(
+                                element
+                            ).get_screenshot(),
+                        }
+                    )
+        except ElementNotFound as err:
+            self.logger.error("Could not validate locator=%s", err)
         return locators
 
     def list_windows(self, exclude_titles=None) -> OpenWindows:
@@ -184,7 +190,7 @@ class WindowsDriver:
             windows = []
             try:
                 windows = self._windows_elements.list_windows(icons=True)
-            except TypeError as err:
+            except (TypeError, ElementNotFound) as err:
                 # If windows is closed while listing the windows library
                 # will raise an exception.
                 # The fix need to be done in the windows library side,
@@ -212,9 +218,16 @@ class WindowsDriver:
 
     def focus(self, window: str, locator: str) -> None:
         self.logger.info("Focus element=%s in window=%s", locator, window)
-        with auto.UIAutomationInitializerInThread(debug=True):
-            self._focus_active_window(window)
-            root = self._windows_elements.get_element(f"name:{window}")
-            element = self._windows_elements.get_element(locator, 8, root)
-            rect = Rectangle.from_element(element)
-            self._draw_borders(rect, COLOR_RED)
+        element_found = False
+        try:
+            with auto.UIAutomationInitializerInThread(debug=True):
+                self._focus_active_window(window)
+                root = self._windows_elements.get_element(f"name:{window}")
+                element = self._windows_elements.get_element(locator, 8, root)
+                rect = Rectangle.from_element(element)
+                self._draw_borders(rect, COLOR_RED)
+                element_found = True
+        except ElementNotFound as err:
+            self.logger.error(f"Could not focus on {locator=} with {err=}")
+        if not element_found:
+            raise ElementNotFound(f"Could not focus on locator: {locator}")
